export declare class Storage<T = unknown> {
    private data;
    constructor();
    /**
     * Get key name by index
     * @param n index
     * @returns key or undefined if index is out of bounds
     */
    key(n: number): string | undefined;
    /**
     * Get value by key
     * @param key The key to retrieve
     * @returns value if present else `undefined`
     */
    getItem(key: string): T | undefined;
    /**
     * Get multiple values by their keys
     * @param keys Array of keys
     * @returns Object with keys and their corresponding values
     */
    multiGet(keys: string[]): Record<string, T | undefined>;
    /**
     * Get all key-value pairs
     * @returns Object with all keys and their corresponding values
     */
    getAllItems(): Record<string, T>;
    /**
     * Get how many key-value pairs are stored
     */
    get length(): number;
    /**
     * Store key-value pair
     * @param key The key to store the value under
     * @param value The value to store
     */
    setItem(key: string, value: T): void;
    /**
     * Store multiple key-value pairs
     * @param keyValuePairs Array of [key, value] pairs or object with key-value pairs
     */
    multiSet(keyValuePairs: [string, T][] | Record<string, T>): void;
    private deepMerge;
    /**
     * Merge an object value with an existing value stored at the given key
     * @param key The key to merge the value under
     * @param value Object to merge
     * @returns The merged object or undefined if the existing value is not mergeable
     */
    mergeItem(key: string, value: Record<string, unknown>): Record<string, unknown> | undefined;
    /**
     * Merge multiple objects with their corresponding values
     * @param keyValuePairs Array of [key, value] pairs or object with key-value pairs
     * @returns Object with keys and their merged values
     */
    multiMerge(keyValuePairs: [string, Record<string, unknown>][] | Record<string, Record<string, unknown>>): Record<string, Record<string, unknown> | undefined>;
    /**
     * Removes value by key
     * @param key The key to remove
     */
    removeItem(key: string): void;
    /**
     * Remove multiple values by their keys
     * @param keys Array of keys to remove
     */
    multiRemove(keys: string[]): void;
    /**
     * Clear all key-value pairs
     */
    clear(): void;
    /**
     * Get all keys
     * @returns Array of all keys
     */
    getAllKeys(): string[];
}
declare const SessionStorage: Storage<unknown>;
export default SessionStorage;
//# sourceMappingURL=index.d.ts.map